
Changelog
=========

0.1.2 (2022-02-01)
------------------

* Given zero values for B_iso are now ignored.
* Added an option to add some work-related options.


0.1.1 (2022-01-05)
------------------

* Now checks for negative fractional coordinates
* Adds MVW(0,0,0) to strs
* Adds a comment containing the original unit cell prms so you can easily undo them


0.1.0 (2021-11-07)
------------------

* It looks like everything is working!

0.0.0 (2021-11-07)
------------------

* First release on PyPI.
